MethodChannelEsimManager class
An implementation of EsimManagerPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- EsimManagerPlatform
- MethodChannelEsimManager
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
installEvents
→ Stream<
InstallEvent> -
A typed install event that contains a parsed InstallResult with raw payload.
no setteroverride
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
-
onInstallResult
→ Stream<
Map< String, dynamic> > -
Stream that emits platform install results (raw payloads).
Each event is a map with at least
requestIdandresultentries as provided by the platform.no setteroverride - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getActiveProfile(
) → Future< EsimProfile?> -
Returns the currently active profile if any.
override
-
getPlatformVersion(
) → Future< String?> -
Existing helper kept for backwards compatibility.
override
-
installEsim(
String lpa) → Future< bool> -
Installs an eSIM profile.
On Android: lpa is the LPA code/string
On iOS: lpa is the LPA code/string for universal link provisioning
override
-
isEsimSupported(
) → Future< bool> -
Returns whether the current device/platform supports eSIM operations.
override
-
listProfiles(
) → Future< List< EsimProfile> > -
Lists installed eSIM profiles.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeProfile(
String profileId) → Future< bool> -
Removes an installed profile by id.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited