EsimManagerPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- EsimManagerPlatform
- Implementers
Constructors
- EsimManagerPlatform()
- Constructs a EsimManagerPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
installEvents
→ Stream<
InstallEvent> -
A typed install event that contains a parsed InstallResult with raw payload.
no setter
-
onInstallResult
→ Stream<
Map< String, dynamic> > -
Stream that emits platform install results (raw payloads).
Each event is a map with at least
requestIdandresultentries as provided by the platform.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getActiveProfile(
) → Future< EsimProfile?> - Returns the currently active profile if any.
-
getPlatformVersion(
) → Future< String?> - Existing helper kept for backwards compatibility.
-
installEsim(
String lpa) → Future< bool> - Installs an eSIM profile. On Android: lpa is the LPA code/string On iOS: lpa is the LPA code/string for universal link provisioning
-
isEsimSupported(
) → Future< bool> - Returns whether the current device/platform supports eSIM operations.
-
listProfiles(
) → Future< List< EsimProfile> > - Lists installed eSIM profiles.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeProfile(
String profileId) → Future< bool> - Removes an installed profile by id.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ EsimManagerPlatform
-
The default instance of EsimManagerPlatform to use.
getter/setter pair